pub struct Key {
pub topic: String,
pub key: Vec<u8>,
}Fields
topic: Stringkey: Vec<u8>Implementations
Sourceimpl Key
impl Key
Sourcepub fn into_bytes(self) -> Result<Vec<u8>>
pub fn into_bytes(self) -> Result<Vec<u8>>
Create a vector of bytes from the key.
The key is a concatenation of the topic and the key, separated by a slash.
Errors
Returns an error if the topic contains a slash.
Example
use hyveos_core::dht::Key;
let key = Key {
topic: "topic".to_string(),
key: "key".into(),
};
let bytes = key.into_bytes().unwrap();
assert_eq!(bytes, b"topic/key");Sourcepub fn from_bytes(bytes: Vec<u8>) -> Result<Self>
pub fn from_bytes(bytes: Vec<u8>) -> Result<Self>
Create a key from a vector of bytes.
The bytes should be a concatenation of the topic and the key, separated by a slash.
Errors
Returns an error if the bytes do not contain a slash or if the topic is not valid UTF-8.
Example
use hyveos_core::dht::Key;
let bytes = b"topic/key".to_vec();
let key = Key::from_bytes(bytes).unwrap();
assert_eq!(key.topic, "topic");
assert_eq!(&key.key, b"key");Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Key
impl<'de> Deserialize<'de> for Key
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for Key
impl StructuralPartialEq for Key