Debug

Trait Debug 

pub trait Debug:
    Send
    + Sync
    + 'static {
    type SubscribeMeshTopologyStream: Stream<Item = Result<MeshTopologyEvent, Status>> + Send + 'static;
    type SubscribeMessagesStream: Stream<Item = Result<MessageDebugEvent, Status>> + Send + 'static;

    // Required methods
    fn subscribe_mesh_topology<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Empty>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Self::SubscribeMeshTopologyStream>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn subscribe_messages<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Empty>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Self::SubscribeMessagesStream>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with DebugServer.

Required Associated Types

type SubscribeMeshTopologyStream: Stream<Item = Result<MeshTopologyEvent, Status>> + Send + 'static

Server streaming response type for the SubscribeMeshTopology method.

type SubscribeMessagesStream: Stream<Item = Result<MessageDebugEvent, Status>> + Send + 'static

Server streaming response type for the SubscribeMessages method.

Required Methods

fn subscribe_mesh_topology<'life0, 'async_trait>( &'life0 self, request: Request<Empty>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::SubscribeMeshTopologyStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Subscribe to mesh topology events to get notified when the mesh topology changes

fn subscribe_messages<'life0, 'async_trait>( &'life0 self, request: Request<Empty>, ) -> Pin<Box<dyn Future<Output = Result<Response<Self::SubscribeMessagesStream>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Subscribe to message debug events to get notified when messages are sent

Implementors