Scripting

Trait Scripting 

pub trait Scripting:
    Send
    + Sync
    + 'static {
    // Required methods
    fn deploy_script<'life0, 'async_trait>(
        &'life0 self,
        request: Request<DeployScriptRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Id>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn list_running_scripts<'life0, 'async_trait>(
        &'life0 self,
        request: Request<ListRunningScriptsRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<RunningScripts>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn stop_script<'life0, 'async_trait>(
        &'life0 self,
        request: Request<StopScriptRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Empty>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn get_own_id<'life0, 'async_trait>(
        &'life0 self,
        request: Request<Empty>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<Id>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with ScriptingServer.

Required Methods

fn deploy_script<'life0, 'async_trait>( &'life0 self, request: Request<DeployScriptRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Id>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Deploy a script to a peer and get the id of the deployed script

fn list_running_scripts<'life0, 'async_trait>( &'life0 self, request: Request<ListRunningScriptsRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<RunningScripts>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

List running scripts on a peer

fn stop_script<'life0, 'async_trait>( &'life0 self, request: Request<StopScriptRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<Empty>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Stop a running script on a peer

fn get_own_id<'life0, 'async_trait>( &'life0 self, request: Request<Empty>, ) -> Pin<Box<dyn Future<Output = Result<Response<Id>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get the id of the current script

Implementors