pub struct ListRunningScriptsRequest {
pub peer: Option<Peer>,
}Expand description
A request to list running scripts on a peer
Fields
peer: Option<Peer>The peer can be empty if the scripts running on self should be listed