pub struct MessageDebugEvent {
pub sender: Peer,
pub event: Option<Event>,
}Expand description
A message debug event
Fields
sender: Peerevent: Option<Event>Trait Implementations
Sourceimpl Clone for MessageDebugEvent
impl Clone for MessageDebugEvent
Sourcefn clone(&self) -> MessageDebugEvent
fn clone(&self) -> MessageDebugEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageDebugEvent
impl Debug for MessageDebugEvent
Sourceimpl Default for MessageDebugEvent
impl Default for MessageDebugEvent
Sourceimpl From<MessageDebugEvent> for MessageDebugEvent
impl From<MessageDebugEvent> for MessageDebugEvent
Sourcefn from(event: MessageDebugEvent) -> Self
fn from(event: MessageDebugEvent) -> Self
Converts to this type from the input type.
Sourceimpl Message for MessageDebugEvent
impl Message for MessageDebugEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MessageDebugEvent
impl PartialEq for MessageDebugEvent
Sourceimpl TryFrom<MessageDebugEvent> for MessageDebugEvent
impl TryFrom<MessageDebugEvent> for MessageDebugEvent
impl StructuralPartialEq for MessageDebugEvent