pub struct StopScriptRequest {
pub id: Id,
pub peer: Option<Peer>,
}Expand description
A request to stop a running script on a peer
Fields
id: Idpeer: Option<Peer>The peer can be empty if the script should be stopped on self